==> react-atom-tag-2.53.0.tgz: package/lib/Standard.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { onHandler } from './constants.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var StandardTag = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var className = _ref.className,
    closeIcon = _ref.closeIcon,
    icon = _ref.icon,
    label = _ref.label,
    _ref$onClose = _ref.onClose,
    onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
    value = _ref.value,
    readOnly = _ref.readOnly,
    disabled = _ref.disabled,
    title = _ref.title;
  return /*#__PURE__*/_jsxs("span", _extends({
    ref: forwardedRef,
    className: cx(className, closeIcon && 'sui-AtomTag-hasClose')
  }, disabled && {
    'aria-disabled': disabled
  }, readOnly && !disabled && {
    'aria-readonly': readOnly
  }, {
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-icon",
      children: icon
    }), label ? /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-label",
      title: title || label,
      children: label
    }) : null, closeIcon && !(disabled || readOnly) && /*#__PURE__*/_jsx("span", {
      role: "button",
      className: "sui-AtomTag-closeable",
      onClick: onHandler({
        disabled: disabled,
        readOnly: readOnly
      }, onClose, {
        value: value,
        label: label
      }),
      children: /*#__PURE__*/_jsx("span", {
        className: "sui-AtomTag-closeableIcon sui-AtomTag-secondary-icon",
        children: closeIcon
      })
    })]
  }));
});
StandardTag.propTypes = {
  readOnly: PropTypes.bool,
  disabled: PropTypes.bool,
  onClose: PropTypes.func,
  closeIcon: PropTypes.node,
  icon: PropTypes.node,
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
  className: PropTypes.string,
  title: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};
export default StandardTag;

==> react-atom-tag-2.54.0.tgz: package/lib/Standard.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { onHandler } from './constants.js';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var StandardTag = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var className = _ref.className,
    closeIcon = _ref.closeIcon,
    icon = _ref.icon,
    label = _ref.label,
    _ref$onClose = _ref.onClose,
    onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
    value = _ref.value,
    readOnly = _ref.readOnly,
    disabled = _ref.disabled,
    title = _ref.title;
  return /*#__PURE__*/_jsxs("span", _extends({
    ref: forwardedRef,
    className: cx(className, closeIcon && 'sui-AtomTag-hasClose')
  }, disabled && {
    'aria-disabled': disabled
  }, readOnly && !disabled && {
    'aria-readonly': readOnly
  }, {
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-icon",
      children: icon
    }), label ? /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-label",
      title: title || label,
      children: label
    }) : null, closeIcon && !(disabled || readOnly) && /*#__PURE__*/_jsx("span", {
      role: "button",
      className: "sui-AtomTag-closeable",
      onClick: onHandler({
        disabled: disabled,
        readOnly: readOnly
      }, onClose, {
        value: value,
        label: label
      }),
      children: /*#__PURE__*/_jsx("span", {
        className: "sui-AtomTag-closeableIcon sui-AtomTag-secondary-icon",
        children: closeIcon
      })
    })]
  }));
});
StandardTag.propTypes = {
  readOnly: PropTypes.bool,
  disabled: PropTypes.bool,
  onClose: PropTypes.func,
  closeIcon: PropTypes.node,
  icon: PropTypes.node,
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
  className: PropTypes.string,
  title: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};
export default StandardTag;
